**Unreleased**

**v0.3.2**
* Improve usage documentation
* Allow using `CONJURRC` env var for specifying config file
* Fix package to include `requirements.txt`

**v0.3.1**
* make the certificate verification actually work
